# UCurriculum-Student🧍

Python library dedicated to extract the information from the "Seguimiento Curricular" page of the Pontifical Catholic University of Chile (UC); in particular, the actual courses taken by a student.

## Installation

The library is avaible on PyPi:

```shell
$ pip install something
```
